Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1327)

Unified Diff: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestContactDetailsTest.java

Issue 2447953002: [Payments] Add metrics for the new payer name contact info. (Closed)
Patch Set: Nits Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestContactDetailsTest.java
diff --git a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestContactDetailsTest.java b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestContactDetailsTest.java
index 1c36989c6602e659d81373a241cf10265126e851..0d248749d259617d6d804b659875dd85fa4b0424 100644
--- a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestContactDetailsTest.java
+++ b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestContactDetailsTest.java
@@ -180,9 +180,9 @@ public class PaymentRequestContactDetailsTest extends PaymentRequestTestBase {
}
/**
* Test that starting a payment request that requires the user's email address and phone number
* results in the appropriate metric being logged in the PaymentRequest.RequestedInformation
* histogram.
*/
@MediumTest
@Feature({"Payments"})
@@ -194,7 +194,8 @@ public class PaymentRequestContactDetailsTest extends PaymentRequestTestBase {
// Make sure that only the appropriate enum value was logged.
for (int i = 0; i < PaymentRequestMetrics.REQUESTED_INFORMATION_MAX; ++i) {
assertEquals((i == (PaymentRequestMetrics.REQUESTED_INFORMATION_EMAIL
- | PaymentRequestMetrics.REQUESTED_INFORMATION_PHONE) ? 1 : 0),
+ | PaymentRequestMetrics.REQUESTED_INFORMATION_PHONE
+ | PaymentRequestMetrics.REQUESTED_INFORMATION_NAME) ? 1 : 0),
RecordHistogram.getHistogramValueCountForTesting(
"PaymentRequest.RequestedInformation", i));
}
@@ -180,9 +180,9 @@ public class PaymentRequestContactDetailsTest extends PaymentRequestTestBase {
}
/**
- * Test that starting a payment request that requires the user's email address and phone number
- * results in the appropriate metric being logged in the PaymentRequest.RequestedInformation
- * histogram.
+ * Test that starting a payment request that requires the user's email address, phone number and
+ * name results in the appropriate metric being logged in the
+ * PaymentRequest.RequestedInformation histogram.
*/

Powered by Google App Engine
This is Rietveld 408576698